require(xtable)

data <- read.csv("~/Dropbox/crabbing/clean_data/crabs.csv")
#Remove missing data
data <- data[!is.na(data$diameter) & data$diameter > 0,]
data$injury <- as.numeric(data$pincers!=2 | data$legs!=8)
data <- data[!is.na(data$pincers),]
data <- data[!is.na(data$location),]
data <- data[data$sex=="male" | data$sex=="female",]
data <- data[data$time.day != "journalist",]#Ignore a deployment to show a journalist what we did
data$time.day <- factor(data$time.day)
data$sex <- factor(data$sex)
names(data)[8] <- "length.deployed"
data$source <- relevel(data$source, "us")
data$unique.id <- with(data, paste(day,trap,time.day,se="_"))
data$no.trap <- as.numeric(table(data$unique.id)[data$unique.id])
data$time.day <- relevel(data$time.day, "4-tide")

#Can't fit a maximal model (numerical fitting problems, probably because of infinite directions of recession); finite additive model
#Note: singularity for the 'Cromer' time of day is not an issue; we don't know the time of day of all the Cromer samples, so they have their own factor level which (therefore) is identical to 'cromer'. Deletion doesn't affect results, as you can check for yourself.
model <- glm(injury ~ location + source + length.deployed + sex + diameter + no.trap + time.day, data=data, family=binomial)
xtable(model, digits=c(3,3,5,3,4))

jpeg("~/Dropbox/crabbing/injury.jpeg", width=1000, height=1000, quality=100)
with(data, boxplot(diameter ~ injury, horizontal=TRUE, names=c("Healthy", "Injured"), xlab="Carapace diameter", pch=20, cex.lab=2, cex.axis=2))
diameter <- seq(from=min(data$diameter), to=max(data$diameter), by=0.05)
predict <- predict(model, data.frame(diameter=diameter,sex=rep("female",length(diameter)), location=rep("control",length(diameter)), length.deployed=rep(45,length(diameter)), no.trap=rep(median(data$no.trap),length(diameter)), source=rep("us", length(diameter)), time.day=rep("4-tide", length(diameter))), type="response")
lines(predict+1 ~ seq(from=min(data$diameter), to=max(data$diameter), by=0.05), col="black", lwd=5, lty=2)
predict <- predict(model, data.frame(diameter=diameter,sex=rep("male",length(diameter)), location=rep("control",length(diameter)), length.deployed=rep(45,length(diameter)), no.trap=rep(median(data$no.trap),length(diameter)), source=rep("us", length(diameter)), time.day=rep("4-tide", length(diameter))), type="response")
lines(predict+1 ~ seq(from=min(data$diameter), to=max(data$diameter), by=0.05), col="black", lwd=5)
predict <- predict(model, data.frame(diameter=diameter,sex=rep("male",length(diameter)), location=rep("harbour",length(diameter)), length.deployed=rep(45,length(diameter)), no.trap=rep(median(data$no.trap),length(diameter)), source=rep("us", length(diameter)), time.day=rep("4-tide", length(diameter))), type="response")
lines(predict+1 ~ seq(from=min(data$diameter), to=max(data$diameter), by=0.05), col="darkgrey", lwd=5)
predict <- predict(model, data.frame(diameter=diameter,sex=rep("male",length(diameter)), location=rep("harbour",length(diameter)), length.deployed=rep(45,length(diameter)), no.trap=rep(median(data$no.trap),length(diameter)), source=rep("them", length(diameter)), time.day=rep("4-tide", length(diameter))), type="response")
lines(predict+1 ~ seq(from=min(data$diameter), to=max(data$diameter), by=0.05), col="red", lwd=5)
predict <- predict(model, data.frame(diameter=diameter,sex=rep("male",length(diameter)), location=rep("cromer",length(diameter)), length.deployed=rep(45,length(diameter)), no.trap=rep(median(data$no.trap),length(diameter)), source=rep("them", length(diameter)), time.day=rep("4-tide", length(diameter))), type="response")
lines(predict+1 ~ seq(from=min(data$diameter), to=max(data$diameter), by=0.05), col="red", lwd=5, lty=2)
dev.off()

#Survey data
data <- read.csv("~/Dropbox/crabbing/clean_data/survey.csv")
data$duration <- factor(data$duration, c("30-1hr", "1hr-2hr", "2hr+", "2hr-4hr", "4hr+", "full day"))
levels(data$duration)[1] <- "30mn-1hr"
levels(data$duration)[3:4] <- "2hr+"
levels(data$duration)[4:5] <- "4hr+"
data$crabs.bucket <- factor(data$crabs.bucket, c("0", "1-5", "5-10", "10-20", "20+", "20-40", "40+"))
levels(data$crabs.bucket)[5:6] <- "20+"
data$sign. <- factor(data$sign., c("not interested", "apathetic", "interested", "very interested"))
data$money.spent <- factor(data$money.spent, c("£0", "<£1", "£1-5", "£5-10", "£10-20", "£20+", "£20-30", "£20-40", "£40+"))
levels(data$money.spent)[1:2] <- "£0-1"
levels(data$money.spent)[5:7] <- "£20+"
levels(data$money.spent)[5:7] <- "£20+"

barplot <- matrix(c(table(data$crabs.bucket), table(data$money.spent),0, table(data$duration),0,0, table(data$sign.),0,0), ncol=4)

jpeg("~/Dropbox/crabbing/survey.jpeg", height=1000, width=1000, quality=100)
layout <- barplot(barplot, col="white", names=c("Crabs per bucket", "Money spent", "Time crabbing", "Sign interest"), cex.axis=2, cex.lab=2, cex=2)
add.labels <- function(labels, x.val){
    text(x.val,labels[1]/2, names(labels)[1], cex=2)
    for(i in seq(from=2, to=length(labels)))
        text(x.val,sum(labels[seq(from=1,to=i-1)])+labels[i]/2, names(labels)[i], cex=2)
}
add.labels(table(data$crabs.bucket), layout[1])
add.labels(table(data$money.spent), layout[2])
add.labels(table(data$duration), layout[3])
add.labels(table(data$sign.), layout[4])
dev.off()
